==> elpa_2022.11.001.orig.tar.gz: elpa-2022.11.001/src/GPU/ROCm/elpa_explicit_name_amd_gpu.cpp <==
//    Copyright 2022, P. Karpov, MPCDF
//
//    This file is part of ELPA.
//
//    The ELPA library was originally created by the ELPA consortium,
//    consisting of the following organizations:
//
//    - Max Planck Computing and Data Facility (MPCDF), formerly known as
//      Rechenzentrum Garching der Max-Planck-Gesellschaft (RZG),
//    - Bergische Universität Wuppertal, Lehrstuhl für angewandte
//      Informatik,
//    - Technische Universität München, Lehrstuhl für Informatik mit
//      Schwerpunkt Wissenschaftliches Rechnen ,
//    - Fritz-Haber-Institut, Berlin, Abt. Theorie,
//    - Max-Plack-Institut für Mathematik in den Naturwissenschaften,
//      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition,
//      and
//    - IBM Deutschland GmbH
//
//
//    This particular source code file contains additions, changes and
//    enhancements authored by Intel Corporation which is not part of
//    the ELPA consortium.
//
//    More information can be found here:
//    http://elpa.mpcdf.mpg.de/
//
//    ELPA is free software: you can redistribute it and/or modify
//    it under the terms of the version 3 of the license of the
//    GNU Lesser General Public License as published by the Free
//    Software Foundation.
//
//    ELPA is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public License
//    along with ELPA. If not, see <http://www.gnu.org/licenses/>
//
//    ELPA reflects a substantial effort on the part of the original
//    ELPA consortium, and we ask you to respect the spirit of the
//    license that we chose: i.e., please contribute any changes you
//    may have back to the original ELPA library distribution, and keep
//    any derivatives of ELPA under the same license that we chose for
//    the original distribution, the GNU Lesser General Public License.
//

#include <cstdio>
#include <hip/hip_runtime.h>

extern "C" {
  
  int is_device_ptr(void *a_void_ptr) {
    hipPointerAttribute_t attributes;
    hipError_t hiperr = hipPointerGetAttributes(&attributes, a_void_ptr);  
    if (hiperr != hipSuccess)
		  {    
		  printf("Warning in is_device_ptr(): hipPointerGetAttributes: %s\n", hipGetErrorString(hiperr));
		  printf("Pointer wasn't allocated via hip, so we use an all host array (a_h_a) function\n");
        return 0;
		  }
    
    if (attributes.memoryType==hipMemoryTypeDevice) return 1;
    else return 0;
  }
  
}

==> elpa_2024.05.001.orig.tar.gz: elpa-2024.05.001/src/GPU/ROCm/elpa_explicit_name_amd_gpu.cpp <==
//    Copyright 2022, P. Karpov, MPCDF
//
//    This file is part of ELPA.
//
//    The ELPA library was originally created by the ELPA consortium,
//    consisting of the following organizations:
//
//    - Max Planck Computing and Data Facility (MPCDF), formerly known as
//      Rechenzentrum Garching der Max-Planck-Gesellschaft (RZG),
//    - Bergische Universität Wuppertal, Lehrstuhl für angewandte
//      Informatik,
//    - Technische Universität München, Lehrstuhl für Informatik mit
//      Schwerpunkt Wissenschaftliches Rechnen ,
//    - Fritz-Haber-Institut, Berlin, Abt. Theorie,
//    - Max-Plack-Institut für Mathematik in den Naturwissenschaften,
//      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition,
//      and
//    - IBM Deutschland GmbH
//
//
//    This particular source code file contains additions, changes and
//    enhancements authored by Intel Corporation which is not part of
//    the ELPA consortium.
//
//    More information can be found here:
//    http://elpa.mpcdf.mpg.de/
//
//    ELPA is free software: you can redistribute it and/or modify
//    it under the terms of the version 3 of the license of the
//    GNU Lesser General Public License as published by the Free
//    Software Foundation.
//
//    ELPA is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public License
//    along with ELPA. If not, see <http://www.gnu.org/licenses/>
//
//    ELPA reflects a substantial effort on the part of the original
//    ELPA consortium, and we ask you to respect the spirit of the
//    license that we chose: i.e., please contribute any changes you
//    may have back to the original ELPA library distribution, and keep
//    any derivatives of ELPA under the same license that we chose for
//    the original distribution, the GNU Lesser General Public License.
//

#include <cstdio>
#include <hip/hip_runtime.h>

extern "C" {
  
  int is_device_ptr(void *a_void_ptr) {
    hipPointerAttribute_t attributes;
    hipError_t hiperr = hipPointerGetAttributes(&attributes, a_void_ptr);  
    if (hiperr != hipSuccess)
		  {    
		  printf("Warning in is_device_ptr(): hipPointerGetAttributes: %s\n", hipGetErrorString(hiperr));
		  printf("Pointer wasn't allocated via hip, so we use an all host array (a_h_a) function\n");
        hiperr = hipGetLastError(); // reset the error
        return 0;
		  }
#ifdef HAVE_OLD_HIP_TYPESTRUCTURE
    if (attributes.memoryType==hipMemoryTypeDevice) return 1;
#else
    if (attributes.type==hipMemoryTypeDevice) return 1;
#endif
    else return 0;
  }
  
}
